# OrthNet
TensorFlow and PyTorch layers for generating multi-dimensional Orthogonal Polynomials

---
## Orthogonal polynomials supported:
- [Legendre polynomial](https://en.wikipedia.org/wiki/Legendre_polynomials)
- [Laguerre polynomial](https://en.wikipedia.org/wiki/Laguerre_polynomials)
- [Hermite polynomial](https://en.wikipedia.org/wiki/Hermite_polynomials)
  - hermite: He(x) in Wiki, the poly in probability theory
  - hermite2: H(x) in Wiki, the poly in physics
- [Chebyshev polynomial](https://en.wikipedia.org/wiki/Chebyshev_polynomials)
  - chebyshev: T(x) in Wiki, of the first kind
  - chebyshev2: U(x) in Wiki, of the second kind
